@@ -3,13 +3,10 @@ package Pistachio::Token::Transformer::Perl5;
 
 use strict;
 use warnings;
-our $VERSION = '0.06'; # VERSION
+our $VERSION = '0.07'; # VERSION
 
 use Pistachio::Token::Transformer::Rule;
 
-use JBD::Core::Exporter;
-our @EXPORT_OK = qw(transform_rules);
-
 # @return arrayref    Pistachio::Token::Transformer::Rules
 sub transform_rules {
     my @rules;
@@ -146,7 +143,7 @@ Pistachio::Token::Transformer::Perl5 - provides transform_rules(), which returns
 
 =head1 VERSION
 
-version 0.06
+version 0.07
 
 =head1 AUTHOR
 
